@@ -360,15 +360,25 @@ pub fn parse_block(tokens: Vec<Token>) -> (LiteBlock, Option<ParseError>) {
     // - semicolon
     while let Some(token) = tokens.next() {
         match &token.contents {
-            TokenContents::EOL => {
+            TokenContents::Eol => {
                 // If we encounter two newline characters in a row, use a special eoleol event,
                 // which allows the parser to discard comments that shouldn't be treated as
                 // documentation for the following item.
-                if let Some(Token {
-                    contents: TokenContents::EOL,
-                    ..
-                }) = tokens.peek()
-                {
+                let last_was_comment = std::matches!(
+                    parser.prev_token,
+                    Some(Token {
+                        contents: TokenContents::Comment(..),
+                        ..
+                    })
+                );
+                let next_is_eol = std::matches!(
+                    tokens.peek(),
+                    Some(Token {
+                        contents: TokenContents::Eol,
+                        ..
+                    })
+                );
+                if last_was_comment && next_is_eol {
                     tokens.next();
                     parser.eoleol();
                 } else {
@@ -480,7 +490,7 @@ pub fn lex(input: &str, span_offset: usize) -> (Vec<Token>, Option<ParseError>)
             let idx = *idx;
             let _ = char_indices.next();
             output.push(Token::new(
-                TokenContents::EOL,
+                TokenContents::Eol,
                 Span::new(span_offset + idx, span_offset + idx + 1),
             ));
         } else if *c == '#' {
