@@ -4,9 +4,9 @@ extern crate derive_is_enum_variant;
 extern crate derive_new;
 
 mod errors;
+mod flag;
 mod lex;
 mod parse;
-mod path;
 mod scope;
 mod shapes;
 mod signature;
@@ -14,8 +14,6 @@ mod signature;
 pub use lex::lexer::{lex, parse_block};
 pub use lex::tokens::{LiteBlock, LiteCommand, LiteGroup, LitePipeline};
 pub use parse::{classify_block, garbage, parse, parse_full_column_path, parse_math_expression};
-pub use path::expand_ndots;
-pub use path::expand_path;
 pub use scope::ParserScope;
 pub use shapes::shapes;
 pub use signature::{Signature, SignatureRegistry};
